package com.zd.exam.service;

import java.util.List;
import java.util.Map;

import com.zd.exam.domain.ElPractise;
import com.zd.exam.domain.ElPractiseQu;

/**
 * 练习记录Service接口
 *
 * @author liubo
 * @date 2021-12-14
 */
public interface IElPractiseService {
    /**
     * 查询练习记录
     *
     * @param id 练习记录主键
     * @return 练习记录
     */
    public ElPractise selectElPractiseById(Long id);

    /**
     * 查询练习记录列表
     *
     * @param elPractise 练习记录
     * @return 练习记录集合
     */
    public List<ElPractise> selectElPractiseList(ElPractise elPractise);

    /**
     * 新增练习记录
     *
     * @param elPractise 练习记录
     * @return 结果
     */
    public ElPractise insertElPractise(ElPractise elPractise);

    /**
     * 修改练习记录
     *
     * @param elPractise 练习记录
     * @return 结果
     */
    public int updateElPractise(ElPractise elPractise);

    /**
     * 批量删除练习记录
     *
     * @param ids 需要删除的练习记录主键集合
     * @return 结果
     */
    public int deleteElPractiseByIds(Long[] ids);

    /**
     * 删除练习记录信息
     *
     * @param id 练习记录主键
     * @return 结果
     */
    public int deleteElPractiseById(Long id);

    Long createPractise(String classifyIds);

    void fillPractiseAnswer(ElPractiseQu practiseQu);

    Map<String, Object> handPractise(ElPractise practise);
}
